@@ -8,6 +8,7 @@ import logging
 
 from aws_lambda_builders.actions import BaseAction, Purpose, ActionFailedError
 from aws_lambda_builders.workflow import BuildMode
+from aws_lambda_builders.architecture import ARM64
 from .utils import OSUtils
 from .dotnetcli import DotnetCLIExecutionError
 
@@ -66,13 +67,14 @@ class RunPackageAction(BaseAction):
     DESCRIPTION = "Execute the `dotnet lambda package` command."
     PURPOSE = Purpose.COMPILE_SOURCE
 
-    def __init__(self, source_dir, subprocess_dotnet, artifacts_dir, options, mode, os_utils=None):
+    def __init__(self, source_dir, subprocess_dotnet, artifacts_dir, options, mode, architecture=None, os_utils=None):
         super(RunPackageAction, self).__init__()
         self.source_dir = source_dir
         self.subprocess_dotnet = subprocess_dotnet
         self.artifacts_dir = artifacts_dir
         self.options = options
         self.mode = mode
+        self.architecture = architecture
         self.os_utils = os_utils if os_utils else OSUtils()
 
     def execute(self):
@@ -82,7 +84,15 @@ class RunPackageAction(BaseAction):
             zipfilename = os.path.basename(os.path.normpath(self.source_dir)) + ".zip"
             zipfullpath = os.path.join(self.artifacts_dir, zipfilename)
 
-            arguments = ["lambda", "package", "--output-package", zipfullpath]
+            arguments = [
+                "lambda",
+                "package",
+                "--output-package",
+                zipfullpath,
+                # Specify the architecture with the --runtime MSBuild parameter
+                "--msbuild-parameters",
+                "--runtime " + self._get_runtime(),
+            ]
 
             if self.mode and self.mode.lower() == BuildMode.DEBUG:
                 LOG.debug("Debug build requested: Setting configuration to Debug")
@@ -102,3 +112,14 @@ class RunPackageAction(BaseAction):
 
         except DotnetCLIExecutionError as ex:
             raise ActionFailedError(str(ex))
+
+    def _get_runtime(self):
+        """
+        Returns the msbuild runtime for the action architecture
+
+        Returns
+        -------
+        str
+            linux-arm64 if ARM64, linux-x64 otherwise
+        """
+        return "linux-arm64" if self.architecture == ARM64 else "linux-x64"
